#!/bin/bash

#######
### Update NGINX configuration '<tags>' with proper values and optionally copy
### to updated directory structure
#######


# text formatting ansi codes
err="\e[1;31m"
ok="\e[1;32m"
warn="\e[93m"
mag="\e[95m"
cyan="\e[96m"
norm="\e[0m"


# set variables
detectedIP=$(ip route get 1 | sed -n 's/^.*src \([0-9.]*\) .*$/\1/p')
regexIP4="(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])"
regexHostname="(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])"


# quick intro for the user
echo -e "\n${mag}This script will customize the provided NGINX template files for your"
echo "environment.  You will be prompted for all necessary information.  After that,"
echo "default error pages will be copied to your webroot and your NGINX configuration"
echo -e "directory structure will be customized.${norm}\n"
echo -e "${warn}You may accept the default option (listed in brackets) by simply"
echo "pressing ENTER (i.e. no answer)."
echo -e "You may exit this script at any prompt by typing 'X'${norm}\n"


### get local IP address
while true; do
    read -p "What is this NGINX machine's primary local IP4 address? (${detectedIP}) " inputIP
    case "${inputIP}" in
        '')
            IP4="${detectedIP}"
            break
            ;;
        [Xx]*)
            echo -e "\n${cyan}---exiting---\n${norm}"
            exit 1
            ;;
        *)
            # check IP for validity
            if [[ "${inputIP}" =~ ^${regexIP4}$ ]]; then
                IP4="${inputIP}"
                break
            else
                echo -e "\n${err}Invalid IP4 format (xxx.xxx.xxx.xxx)${norm}"
            fi
            ;;
    esac
done


### SSL related options
# using certbot?
while true; do
    read -p "Are you using Certbot to handle your SSL certificates? (default: NO) " yn
    case $yn in
        [Yy]*)
            useCertbot=1
            break
            ;;
        [Nn]|'')
            useCertbot=0
            unset CertbotDomain
            break
            ;;
        [Xx]*)
            echo -e "\n${cyan}---exiting---\n${norm}"
            exit 1
            ;;
        *)
            echo -e "\n${err}Please answer (Y)es, (N)o, e(X)it or accept default${norm}"
            ;;
    esac
done            

# using Certbot: get primary domain name since that how Certbot determines paths
if [ "${useCertbot}" -eq 1 ]; then
    while true; do
        read -p "What is the primary domain for your Certbot Certificates? " inputCertbotDomain
        case $inputCertbotDomain in
            '')
                echo -e "\n${err}You cannot have an empty domain name${norm}"
                ;;
            [Xx]*)
                echo -e "\n${cyan}---exiting---\n${norm}"
                exit 1
                ;;
            *)
                # check hostname for validity
                if [[ "${inputCertbotDomain}" =~ ^${regexHostname}$ ]]; then
                    CertbotDomain="${inputCertbotDomain}"
                    break
                else
                    echo -e "\n${err}Invalid hostname${norm}"
                fi
                ;;
        esac
    done
fi


# debug section
echo "Local IP4: $IP4"
echo "Using Certbot: $useCertbot"
echo "CertbotDomain: $CertbotDomain"

exit 0
